@@ -27,7 +27,6 @@ from numpy.random import seed
 import pickle
 from sklearn.preprocessing import MinMaxScaler
 from scivae.validate import Validate
-from tensorflow.keras.callbacks import TensorBoard
 import json
 from scivae import Loss
 from sciutil import SciException, SciUtil
@@ -273,9 +272,6 @@ class VAE(object):
         return [decoder_0, decoder_1]
 
     def build_embedding(self):
-        # if self.loss.distance_metric == 'mmd':
-        #     self.latent_z = Dense(self.latent_config['num_nodes'], name='z')(self.encoding)
-        # else:
         self.latent_z_mean = Dense(self.latent_config['num_nodes'], name='z_mean')(self.encoding)
         self.latent_z_log_sigma = Dense(self.latent_config['num_nodes'], name='z_log_sigma',
                                         kernel_initializer='zeros')(self.encoding)
@@ -311,7 +307,8 @@ class VAE(object):
         # ------------ Out -----------------------
         self.outputs_y = self.decoder(self.encoder(self.inputs_x)[2])
         self.vae = Model(self.inputs_x, self.outputs_y, name='VAE_' + self.vae_label + '_scivae')
-        if self.config['loss']['loss_type']== 'ssmse':
+
+        if self.config['loss']['loss_type'] == 'ssmse':  # ToDo: Update to re-include the ssMSE
             # We want to pass it also the prediction on the VAE space
             vd = Validate(self.encoder(self.inputs_x)[2], self.labels)
             svm_acc = vd.predict('svm', 'accuracy')
@@ -561,8 +558,7 @@ class VAE(object):
             return optimizers.Adamax(learning_rate=learning_rate, beta_1=beta_1, beta_2=beta_2)
 
         elif optimiser_name == 'adam':
-            return optimizers.Adam(learning_rate=learning_rate, beta_1=beta_1, decay=decay,
-                                   beta_2=beta_2, amsgrad=amsgrad)
+            return optimizers.Adam(learning_rate=learning_rate, beta_1=beta_1, beta_2=beta_2, amsgrad=amsgrad)
 
         elif optimiser_name == 'adadelta':
             return optimizers.Adadelta(learning_rate=learning_rate, rho=rho)
